@@ -13,6 +13,8 @@
 # limitations under the License.
 
 from selenium.webdriver.edge.options import Options
+
+from src.testproject.enums.report_type import ReportType
 from src.testproject.sdk.drivers.webdriver.base import BaseDriver
 
 
@@ -26,6 +28,7 @@ class Edge(BaseDriver):
         project_name (str): Project name to report
         job_name (str): Job name to report
         disable_reports (bool): set to True to disable all reporting (no report will be created on TestProject)
+        report_type (ReportType): Type of report to produce - cloud, local or both.
     """
 
     def __init__(
@@ -36,17 +39,15 @@ class Edge(BaseDriver):
         project_name: str = None,
         job_name: str = None,
         disable_reports: bool = False,
+        report_type: ReportType = ReportType.CLOUD_AND_LOCAL,
     ):
+
         # If no options or capabilities are specified at all, use default Options
         if edge_options is None and desired_capabilities is None:
             caps = Options().to_capabilities()
         else:
             # Specified EdgeOptions take precedence over desired capabilities but either can be used
-            caps = (
-                edge_options.to_capabilities()
-                if edge_options is not None
-                else desired_capabilities
-            )
+            caps = edge_options.to_capabilities() if edge_options is not None else desired_capabilities
 
         super().__init__(
             capabilities=caps,
@@ -54,4 +55,5 @@ class Edge(BaseDriver):
             project_name=project_name,
             job_name=job_name,
             disable_reports=disable_reports,
+            report_type=report_type,
         )
