@@ -16,9 +16,12 @@ import logging
 import queue
 import threading
 import uuid
+
+from distutils.util import strtobool
 from enum import Enum, unique
 from http import HTTPStatus
-from urllib.parse import urljoin
+from typing import Optional
+from urllib.parse import urljoin, urlparse
 
 import requests
 import os
@@ -28,6 +31,7 @@ from requests import HTTPError
 from src.testproject.classes import ActionExecutionResponse
 from src.testproject.classes.resultfield import ResultField
 from src.testproject.enums import ExecutionResultType
+from src.testproject.enums.report_type import ReportType
 from src.testproject.executionresults import OperationResult
 from src.testproject.helpers import ConfigHelper, SeleniumHelper
 from src.testproject.rest import ReportSettings
@@ -37,7 +41,8 @@ from src.testproject.rest.messages import (
     DriverCommandReport,
     StepReport,
     CustomTestReport,
-    AddonExecutionResponse)
+    AddonExecutionResponse,
+)
 from src.testproject.rest.messages.agentstatusresponse import AgentStatusResponse
 from src.testproject.sdk.addons import ActionProxy
 from src.testproject.sdk.exceptions import (
@@ -63,6 +68,7 @@ class AgentClient:
         _remote_address (str): The Agent endpoint
         _capabilities (dict): Additional options to be applied to the driver instance
         _agent_session (AgentSession): stores properties of the current agent session
+        _agent_response (SessionResponse): Session initialization response.
         _token (str): The development token used to authenticate with the Agent
         _report_settings (ReportSettings): Settings (project name, job name) to be included in the report
         _queue (queue.Queue): queue holding reports to be sent to Agent in separate thread
@@ -73,59 +79,76 @@ class AgentClient:
     # Minimum Agent version number that supports session reuse
     MIN_SESSION_REUSE_CAPABLE_VERSION = "0.64.20"
 
+    # Minimum Agent version that supports local reports.
+    MIN_LOCAL_REPORT_SUPPORTED_VERSION = "2.1.0"
+
     # Class variable containing the current known Agent version
     __agent_version: str = None
 
     def __init__(self, token: str, capabilities: dict, report_settings: ReportSettings):
-        self._remote_address = ConfigHelper.get_agent_service_address()
-        self._capabilities = capabilities
         self._agent_session = None
-        self._token = token
-        self._report_settings = report_settings
-        self._queue = queue.Queue()
-
-        self._running = True
-        self._reporting_thread = threading.Thread(
-            target=self.__report_worker, daemon=True
-        )
+        self._agent_response = None
         self._close_socket = False
+        self._remote_address = ConfigHelper.get_agent_service_address()
+        self._report_settings = report_settings
+        self._capabilities = capabilities
+        self._token = token
+        # Attempt to start the session
+        self.__start_session()
+        # Make sure local reports are supported
+        self.__verify_local_reports_supported(report_settings.report_type)
+        # Running after all is initialized successfully
+        self._running = True
+        # After session started and is running, start the reporting thread
+        self._queue = queue.Queue()
+        self._reporting_thread = threading.Thread(target=self.__report_worker, daemon=True)
         self._reporting_thread.start()
 
-        if not self.__start_session():
-            raise SdkException("Failed to start development mode session")
-
     @property
     def agent_session(self):
         """Getter for the Agent session object"""
         return self._agent_session
 
-    def __start_session(self) -> bool:
-        """Starts a new development session with the Agent
+    def __verify_local_reports_supported(self, report_type: ReportType):
+        """Verify that target Agent supports local reports, otherwise throw an exception.
 
-        Returns:
-            bool: True if the session started successfully, False otherwise
+        Args:
+            report_type (ReportType): Report type requested.
+
+        Raises:
+            AgentConnectException when local reports are not supported.
         """
+        if report_type is ReportType.LOCAL and version.parse(self.__agent_version) < version.parse(
+            self.MIN_LOCAL_REPORT_SUPPORTED_VERSION
+        ):
+            raise AgentConnectException(
+                f"Target Agent version [{self.__agent_version}] doesn't support local reports."
+                f" Upgrade the Agent to the latest version and try again."
+            )
+
+    def __start_session(self):
+        """Starts a new development session with the Agent"""
         sdk_version = ConfigHelper.get_sdk_version()
 
         logging.info(f"SDK version: {sdk_version}")
 
-        start_session_response = self._request_session_from_agent()
+        self._request_session_from_agent()
 
-        AgentClient.__agent_version = start_session_response.agent_version
+        AgentClient.__agent_version = self._agent_response.agent_version
 
         self._agent_session = AgentSession(
-            start_session_response.server_address,
-            start_session_response.session_id,
-            start_session_response.dialect,
-            start_session_response.capabilities,
+            self._agent_response.server_address,
+            self._agent_response.session_id,
+            self._agent_response.dialect,
+            self._agent_response.capabilities,
         )
 
         SocketManager.instance().open_socket(
-            self._remote_address, start_session_response.dev_socket_port
+            urlparse(self._remote_address).hostname,
+            self._agent_response.dev_socket_port,
         )
 
         logging.info("Development session started...")
-        return True
 
     @staticmethod
     def can_reuse_session() -> bool:
@@ -137,15 +160,14 @@ class AgentClient:
         if AgentClient.__agent_version is None:
             return False
 
-        return version.parse(
-            AgentClient.__agent_version
-        ) >= version.parse(AgentClient.MIN_SESSION_REUSE_CAPABLE_VERSION)
+        return version.parse(AgentClient.__agent_version) >= version.parse(
+            AgentClient.MIN_SESSION_REUSE_CAPABLE_VERSION
+        )
 
-    def _request_session_from_agent(self) -> SessionResponse:
+    def _request_session_from_agent(self):
         """Creates and sends a session request object
 
-        Returns:
-            SessionResponse: object containing the response to the session request
+        Sets the SessionResponse: object containing the response to the session request
         """
         session_request = SessionRequest(self._capabilities, self._report_settings)
 
@@ -158,63 +180,41 @@ class AgentClient:
                 session_request.to_json(),
             )
         except requests.exceptions.ConnectionError:
-            logging.error(
-                f"Could not start new session on {self._remote_address}. Is your Agent running?"
-            )
-            logging.error(
-                "You can download the TestProject Agent from https://app.testproject.io/#/agents"
-            )
-            raise AgentConnectException(
-                f"Connection error trying to connect to Agent on {self._remote_address}"
-            )
+            logging.error(f"Could not start new session on {self._remote_address}. Is your Agent running?")
+            logging.error("You can download the TestProject Agent from https://app.testproject.io/#/agents")
+            raise AgentConnectException(f"Connection error trying to connect to Agent on {self._remote_address}")
 
         if not response.passed:
             self.__handle_new_session_error(response)
 
-        # The generic driver returns a partial response, so we have to create some fields ourselves
-        session_id = response.data.get("sessionId", uuid.uuid4())
-
-        dialect = response.data.get("dialect")
-
-        capabilities = response.data.get("capabilities", {})
-
-        agent_version = response.data.get("version")
-
-        # If driver is Generic, supply None as the server address.
-        server_address = response.data.get("serverAddress")
-
-        start_session_response = SessionResponse(
+        self._agent_response = SessionResponse(
             dev_socket_port=response.data["devSocketPort"],
-            server_address=server_address,
-            session_id=session_id,
-            dialect=dialect,
-            capabilities=capabilities,
-            agent_version=agent_version,
+            server_address=response.data.get("serverAddress"),
+            session_id=response.data.get("sessionId", uuid.uuid4()),
+            dialect=response.data.get("dialect"),
+            capabilities=response.data.get("capabilities", {}),
+            agent_version=response.data.get("version"),
+            local_report=response.data.get("localReport"),
         )
-        return start_session_response
 
     def update_job_name(self, job_name):
         """Sends HTTP request to Agent to update job name during runtime.
 
-                Args:
-                    job_name (str): new job name to use for the current execution
-                """
-        if os.getenv("TP_UPDATE_JOB_NAME") == "True":
+        Args:
+            job_name (str): new job name to use for the current execution
+        """
+        if strtobool(os.getenv("TP_UPDATE_JOB_NAME")):
             logging.info(f"Updating job name to: {job_name}")
             try:
                 response = self.send_request(
                     "PUT",
                     urljoin(self._remote_address, Endpoint.DevelopmentSession.value),
-                    {"jobName": job_name}
+                    {"jobName": job_name},
                 )
+                if not response.passed:
+                    logging.error("Failed to update job name")
             except requests.exceptions.RequestException:
-                logging.error(
-                    "Failed to update job name"
-                )
-            if not response.passed:
-                logging.error(
-                    "Failed to update job name"
-                )
+                logging.error("Failed to update job name")
 
     def send_request(self, method, path, body=None, params=None) -> OperationResult:
         """Sends HTTP request to Agent
@@ -234,17 +234,13 @@ class AgentClient:
             if method == "GET":
                 response = session.get(path, headers={"Authorization": self._token})
             elif method == "POST":
-                response = session.post(
-                    path, headers={"Authorization": self._token}, json=body
-                )
+                response = session.post(path, headers={"Authorization": self._token}, json=body)
             elif method == "DELETE":
                 response = session.delete(path, headers={"Authorization": self._token})
             elif method == "PUT":
                 response = session.put(path, headers={"Authorization": self._token}, json=body)
             else:
-                raise SdkException(
-                    f"Unsupported HTTP method {method} in send_request()"
-                )
+                raise SdkException(f"Unsupported HTTP method {method} in send_request()")
 
         response_json = {}
         # For some successful calls, the response body will be empty
@@ -259,13 +255,14 @@ class AgentClient:
             response.raise_for_status()
             return OperationResult(True, response.status_code, "", response_json)
         except HTTPError as http_error:
-            return OperationResult(False, response.status_code,
-                                   response_json.get('message', str(http_error)),
-                                   response_json if response_json else None)
+            return OperationResult(
+                False,
+                response.status_code,
+                response_json.get("message", str(http_error)),
+                response_json if response_json else None,
+            )
 
-    def send_action_execution_request(
-        self, codeblock_guid: str, body: dict
-    ) -> ActionExecutionResponse:
+    def send_action_execution_request(self, codeblock_guid: str, body: dict) -> ActionExecutionResponse:
         """Sends HTTP request to Agent
 
         Args:
@@ -289,9 +286,7 @@ class AgentClient:
             result = ExecutionResultType.Failed
         else:
             result = (
-                ExecutionResultType.Passed
-                if response.data["resultType"] == "Passed"
-                else ExecutionResultType.Failed
+                ExecutionResultType.Passed if response.data["resultType"] == "Passed" else ExecutionResultType.Failed
             )
 
         result_data = response.data["outputs"] if response.passed else None
@@ -311,9 +306,7 @@ class AgentClient:
 
         with requests.Session() as session:
             response = session.get(
-                urljoin(
-                    ConfigHelper.get_agent_service_address(), Endpoint.GetStatus.value
-                ),
+                urljoin(ConfigHelper.get_agent_service_address(), Endpoint.GetStatus.value),
                 headers={"Authorization": token},
             )
 
@@ -323,9 +316,7 @@ class AgentClient:
                 response_json = response.json()
                 agent_version = response_json["tag"]
             except ValueError:
-                raise SdkException(
-                    "Could not parse Agent status response: no JSON response body present"
-                )
+                raise SdkException("Could not parse Agent status response: no JSON response body present")
             except KeyError:
                 raise SdkException(
                     "Could not parse Agent status response: element 'tag' not found in JSON response body"
@@ -387,22 +378,26 @@ class AgentClient:
         # Send a stop signal to the thread worker
         self._running = False
 
+        # TODO: Add proper session reuse logic.
+        # Reusing a session means using the same Agent Client for multiple tests,
+        # not just reusing the TCP socket connection.
+        # Until this will be implemented correctly, always close the TCP socket.
+
+        # if not AgentClient.can_reuse_session():
+        self._close_socket = True
+
         # Send a final, empty, report to the queue to ensure that
         # the 'running' condition is evaluated one last time
-        self._queue.put(
-            QueueItem(report_as_json=None, url=None, token=self._token), block=False
-        )
+        self._queue.put(QueueItem(report_as_json=None, url=None, token=self._token), block=False)
 
         # Wait until all items have been reported or timeout passes
         self._reporting_thread.join(timeout=self.REPORTS_QUEUE_TIMEOUT)
         if self._reporting_thread.is_alive():
             # Thread is still alive, so there are unreported items
-            logging.warning(
-                f"There are {self._queue.qsize()} unreported items in the queue"
-            )
+            logging.warning(f"There are {self._queue.qsize()} unreported items in the queue")
 
-        if not AgentClient.can_reuse_session():
-            self._close_socket = True
+        if self._agent_response.local_report:
+            logging.info(f"Execution Report: {self._agent_response.local_report}")
 
     def execute_proxy(self, action: ActionProxy) -> AddonExecutionResponse:
         """Sends a custom action to the Agent
@@ -417,28 +412,37 @@ class AgentClient:
             "POST",
             urljoin(self._remote_address, Endpoint.AddonExecution.value),
             self._create_action_proxy_payload(action),
-            {"skipReporting": "true"}  # Delegate reporting from Agent to SDK.
+            {"skipReporting": "true"},  # Delegate reporting from Agent to SDK.
         )
 
         if operation_result.status_code == HTTPStatus.NOT_FOUND:
-            logging.error(f'Action [{action.proxydescriptor.classname}] in addon [{action.proxydescriptor.guid}]'
-                          f' is not installed in your account.')
+            logging.error(
+                f"Action [{action.proxydescriptor.classname}] in addon [{action.proxydescriptor.guid}]"
+                f" is not installed in your account."
+            )
             raise AddonNotInstalledException
 
-        return AddonExecutionResponse(execution_result_type=(ExecutionResultType.Passed
-                                                             if operation_result.data["resultType"] == "Passed"
-                                                             else ExecutionResultType.Failed),
-                                      message=operation_result.data["message"],
-                                      fields=([] if not operation_result.data['fields']
-                                              else [ResultField(**field) for field in operation_result.data['fields']]))
+        return AddonExecutionResponse(
+            execution_result_type=(
+                ExecutionResultType.Passed
+                if operation_result.data["resultType"] == "Passed"
+                else ExecutionResultType.Failed
+            ),
+            message=operation_result.data["message"],
+            fields=(
+                []
+                if not operation_result.data["fields"]
+                else [ResultField(**field) for field in operation_result.data["fields"]]
+            ),
+        )
 
     @staticmethod
     def _create_action_proxy_payload(action: ActionProxy) -> dict:
         """Creates a payload dictionary that will be transformed to a action JSON request body
-            Args:
-                action (ActionProxy): The action for which a payload should be created
-            Returns:
-                dict: the payload dictionary used to request execution of an action
+        Args:
+            action (ActionProxy): The action for which a payload should be created
+        Returns:
+            dict: the payload dictionary used to request execution of an action
         """
         payload = {
             "guid": action.proxydescriptor.guid,
@@ -451,16 +455,15 @@ class AgentClient:
             )
         return payload
 
-    def __handle_new_session_error(self, response: OperationResult):
-        """ Handles errors occurring on creation of a new session with the Agent
+    @staticmethod
+    def __handle_new_session_error(response: OperationResult):
+        """Handles errors occurring on creation of a new session with the Agent
 
         Args:
             response (OperationResult): response from the Agent
         """
         if response.status_code == HTTPStatus.UNAUTHORIZED:
-            logging.error(
-                "Failed to initialize a session with the Agent - invalid developer token supplied"
-            )
+            logging.error("Failed to initialize a session with the Agent - invalid developer token supplied")
             logging.error(
                 "Get your developer token from https://app.testproject.io/#/integrations/sdk?lang=Python"
                 " and set it in the TP_DEV_TOKEN environment variable"
@@ -488,9 +491,7 @@ class AgentClient:
             if isinstance(item, QueueItem):
                 item.send()
             else:
-                logging.warning(
-                    f"Unknown object of type {type(item)} found on queue, ignoring it.."
-                )
+                logging.warning(f"Unknown object of type {type(item)} found on queue, ignoring it..")
             self._queue.task_done()
         # Close socket only after agent_client is no longer running and all reports in the queue have been sent.
         if self._close_socket:
@@ -506,12 +507,12 @@ class QueueItem:
         token (str): Token used to authenticate with the Agent
 
     Attributes:
-        _report_as_json (dict): JSON payload representing the item to be reported
-        _url (str): Agent endpoint the payload should be POSTed to
+        _report_as_json (Optional[dict]): JSON payload representing the item to be reported
+        _url (Optional[str]): Agent endpoint the payload should be POSTed to
         _token (str): Token used to authenticate with the Agent
     """
 
-    def __init__(self, report_as_json: dict, url: str, token: str):
+    def __init__(self, report_as_json: Optional[dict], url: Optional[str], token: str):
         self._report_as_json = report_as_json
         self._url = url
         self._token = token
@@ -531,9 +532,7 @@ class QueueItem:
             try:
                 response.raise_for_status()
             except HTTPError:
-                logging.error(
-                    f"Reporting to TestProject returned an HTTP {response.status_code}"
-                )
+                logging.error(f"Reporting to TestProject returned an HTTP {response.status_code}")
                 logging.error(f"Response from Agent: {response.text}")
 
 
